# THIS IS SSEC PROPRIETARY SOFTWARE - ITS USE IS RESTRICTED.
#
# *** $Id: makefile,v 1.15 2014/03/12 20:51:25 release Tst $ ***

#-------
# Makefile for McRD.
#
# Before you will be able to run make, you will have to set up your
# environment.
#
# targets of interest:
#	all	(default)	build everything
#	clean			remove intermediate generated files
#	clobber			remove all generated files
#	install.all		does all of these:
#		install.bin	install the binaries
#		install.lib	install the libraries
#		install.inc	install the header files
#		install.data	install the data
#		install.help	install the help
#	uninstall.all		does all of these:
#		uninstall.bin	uninstall the binaries
#		uninstall.lib	uninstall the libraries
#		uninstall.inc	uninstall the header files
#		uninstall.data	uninstall the data
#		uninstall.help	uninstall the help
#	unknown			prints a list of unaccounted-for
#				files in the current directory.
#				Useful for finding garbage files
#				that are not part of or generated
#				from the defined contents of the
#				directory.
#	chksrc			checks that all files required
#				for the build are present
#
# Cannot make 'install' targets depend on the executables directly,
# because that sometimes seems to trigger spurious relinks
# of the executables on certain platforms.
# Also makes 'install' targets really slow.
#
# The difference between 'clean' and 'clobber' is that 'clobber'
# removes all the generated files - including the ones you install,
# while 'clean' removes the generated files, but not any that you
# install.
#
# The general convention for the makefiles is that McIDAS_ROOT is the
# directory under which we find any other packages installed, which
# McINST_ROOT is the directory where this package is to get installed.
# These are not always the same.
#
# Since this is the mcidas makefile, and we require no other packages,
# we use only McINST_ROOT.
#
# Note that in the install targets, we $(LN) the files to the
# installation directories (because it saves space and time).
# However, we only chmod files which are *generated* as part of
# the build.  We rely on files that were part of the distribution
# to have the correct permissions already.
# (We don't want the chmod of the installed file to affect the
# corresponding source file.)
#-------

SHELL			= /bin/sh

# We put 'all' before '.IMPORT', for the sake of make programs
# that don't assign any special meaning to '.IMPORT'.

all			:: env chksrc

.IMPORT			: McINST_ROOT

# Use the -X make directory for all your src, inc, bin and lib needs
McINSTRD_ROOT		= ../..
McSRC			= $(McINSTRD_ROOT)/src
McBIN			= $(McSRC)
McLIB			= $(McSRC)
McINC			= $(McSRC)
LIBMcIDAS		= $(McSRC)/libmcidas.a

#-------
# BINDIR - directory the program binaries get installed in when you say
# 'make install.bin'.
# You can uninstall them from $(BINDIR) by saying 'make uninstall.bin'.
#-------

BINDIR			= $(McINST_ROOT)/bin

#-------
# LIBDIR - directory the program libraries get installed in when you say
# 'make install.lib'.
# You can uninstall them from $(LIBDIR) by saying 'make uninstall.lib'.
#-------

LIBDIR			= $(McINST_ROOT)/lib

#-------
# INCDIR - directory the program libraries get installed in when you say
# 'make install.inc'.
# You can uninstall them from $(INCDIR) by saying 'make uninstall.inc'.
#-------

INCDIR			= $(McINST_ROOT)/inc

#-------
# HELPDIR - directory the help files get installed in when you say
# 'make install.help'.
# You can uninstall them from $(HELPDIR) by saying
# 'make uninstall.help'.
#-------

HELPDIR			= $(McINST_ROOT)/help

#-------
# DATADIR - directory the data files get installed in when you say
# 'make install.data'.
# You can uninstall them from $(DATADIR) by saying
# 'make uninstall.data'.
#
# There are no data files to install right now, but there are some to
# uninstall.  (They get created as needed when you run mcserv commands.)
#-------

DATADIR			= $(McINST_ROOT)/data

# PKGDATA - directory where data files in this package reside, relative
# to here.

PKGDATA			= ../data

# Other required dependencies and arguments
SDILIBDEPS		=
SDILIBARGS		= -L$(McSRC) -lsdi -lmcidas

PKGTIFF			= $(McINSTRD_ROOT)/tiff
PKGGEOTIFF		= $(McINSTRD_ROOT)/libgeotiff
PKGNETCDF		= $(McINSTRD_ROOT)/netcdf
PKGJPEG			= $(McINSTRD_ROOT)/jpeg
PKGZLIB			= $(McINSTRD_ROOT)/zlib
PKGHDF			= $(McINSTRD_ROOT)/hdf
HDFLIBDEPS		= $(PKGHDF)/hdf/src/libdf.a
HDFLIBARGS		= -L. -lsdi -lmcidas $(MCNSL) \
				-L$(PKGHDF)/mfhdf/libsrc/.libs -lmfhdf  \
				-L$(PKGHDF)/hdf/src/.libs -ldf \
				-L$(PKGJPEG) -ljpeg  \
				-L$(PKGZLIB) -lz
NCDFLIBDEPS		= $(PKGNETCDF)/libsrc/libnetcdf.a
NCDFLIBARGS		= -L$(McSRC) -lsdi -lmcidas \
				-L$(PKGNETCDF)/libsrc -lnetcdf


#-------
# MCAR		Archiver script
#
# MCCOMP	Compiler script
#
# TCLCOMP	Tcl-specific compiler script
#
# MCLOG		Logging script
#
# MCMKHELP	Help file making program
#
# MCLN		Installation script
#-------

MCAR			= $(McBIN)/mcar
MCCOMP			= $(McBIN)/mccomp
TCLCOMP			= $(McBIN)/tclcomp
MCLN			= $(McBIN)/mcln
MCLOG			= $(McBIN)/mclog
MCMKHELP		= $(McBIN)/mcmkhelp

#-------
# General macros.
#-------

INCARGS                 = -I. -I$(McINC) \
			  -I$(PKGNETCDF)/libsrc -I$(PKGHDF)/hdf/src \
			  -I$(PKGHDF)/mfhdf/libsrc -I$(PKGJPEG) -I$(PKGZLIB) \
			  -I$(PKGTIFF)/libtiff -I$(PKGGEOTIFF)

# STRIP			= -s
STRIP			=

DEBUG			= -g
# DEBUG			=

BFC			=
# BFC			= -f2c bfc

# compiler & linker command & arguments
COMPARGS                = $(BFC) $(DEBUG) $(VENDOR) $(NOOPT) $(INCARGS)
COMP			= $(MCCOMP) $(COMPARGS)
TCOMP			= $(TCLCOMP) $(COMP)
LINKARGS		= $(BFC) $(DEBUG) $(STRIP)
LINK			= $(MCCOMP) $(LINKARGS) $(VENDOR)
TLINK			= $(TCLCOMP) $(LINK)

# compiler & linker command, with call to logger
COMPCMD			= $(MCLOG) $(COMP)
TCOMPCMD		= $(MCLOG) $(TCOMP)
LINKCMD			= $(MCLOG) $(LINK)
TLINKCMD		= $(MCLOG) $(TLINK)

# SENTINEL		= -sentinel
SENTINEL		=

# abbreviations
C			= $(COMPCMD)
TC			= $(TCOMPCMD)
L			= $(LINKCMD) $(SENTINEL)
TL			= $(TLINKCMD) $(SENTINEL)
LFP			= $(LINKCMD) -fp

# LN - how to install files.  'mcln' will link them if possible, because
# it's faster and saves space.
#
# You can change this to 'cp' if you wish (but remember to change DATALN too)
# 
LN			= $(MCLN)
#
# DATALN performs the same function as LN.  Using $(MCLN) doesn't
# work here, because $(MCLN) uses a relative path.
#
DATALN			= $(MCLN)

# permissions for user-writable data files
RWDATAPERM		= 644
# permissions for read-only data files
RODATAPERM		= 444
# permissions for programs
PROGPERM		= 755
# permissions for libraries
LIBPERM			= $(RWDATAPERM)

# macros used in targets which check for files which are part of the
# source distribution and files which get generated during the build.

CHKGEN1		= $(MAKE): ERROR: Lack files needed for install:
CHKGEN2		= "You must do a 'make' before doing a 'make install'"
CHKGEN			= exit=0				\
			; miss=					\
			; for f in $${1+"$$@"}			\
			; do	if [ ! -f "$$f" ]		\
			;	then	miss="$$miss $$f"	\
			;		exit=1			\
			;	fi				\
			; done					\
			; case $$miss in			\
			  ?*)	echo $(CHKGEN1) $$miss		\
			;	echo				\
			;	echo $(CHKGEN2)			\
			;	echo				\
				;;				\
			  esac					\
			; exit $$exit

CHKSRC1		= $(MAKE): ERROR: Lack files needed for build:
CHKSRC2		= Your package is incomplete.
CHKSRC			= exit=0				\
			; miss=					\
			; for f in $${1+"$$@"}			\
			; do	if [ ! -f "$$f" ]		\
			;	then	miss="$$miss $$f"	\
			;		exit=1			\
			;	fi				\
			; done					\
			; case $$miss in			\
			  ?*)	echo $(CHKSRC1) $$miss		\
			;	echo				\
			;	echo $(CHKSRC2)			\
			;	echo				\
				;;				\
			  esac					\
			; exit $$exit

######################################################################
#-------
# Custom inference rules because of current McIDAS file naming
# conventions that insist on calling source files by names that
# compilers won't accept.  This will change.
#-------

.SUFFIXES:	.hlp .fp .for .pgm .cp .mac .shk .k .gtk .gui

# make .o files from Fortran sources of various names

.f.o:
	@$(C) -c $*.f
.fp.o:
	@$(C) -c $*.fp
.for.o:
	@$(C) -c $*.for
.pgm.o:
	@$(C) -c $*.pgm
.mac.o:
	@$(C) -c $*.mac

# make .o files from C sources of various names

.c.o:
	@$(C) -c $*.c
.cp.o:
	@$(C) -c $*.cp

# make .k executables from .shk shell scripts

.shk.k:
	rm -f $@
	cat $*.shk | sed \
		-e "s;@MCIDAS_GUI_DIRECTORY@;$(GUIDIR);" \
		-e "s;@MCIDAS_DATA_DIRECTORY@;$(DATADIR);" \
		-e "s;@MCWISH_BIN_DIRECTORY@;$(BINDIR);" \
			> $@
	chmod $(PROGPERM) $@

# make .hlp files from .c and .pgm and .mac files

.c.hlp:
	rm -f $*.hlp; $(MCMKHELP) < $*.c > $*.hlp

.cp.hlp:
	rm -f $*.hlp; $(MCMKHELP) < $*.cp > $*.hlp

.pgm.hlp:
	rm -f $*.hlp; $(MCMKHELP) < $*.pgm > $*.hlp

.mac.hlp:
	rm -f $*.hlp; $(MCMKHELP) < $*.mac > $*.hlp

######################################################################
#-------
# The grand overall default target.  When this succeeds, we record it
# in the log file.
#
# The dependency on _all0 is to allow us to log the beginning of the
# build.
#
# The dependency on sh_prog ensures that the $(MCLOG) script is
# available and runnable before we try to run it.
#-------

all			:: _all
			@$(MCLOG) end

all.nogui		:: all
all.nox			:: all

#_all0			: cosh_prog sh_prog
#_all0			: sh_prog
#			@$(MCLOG) begin

######################################################################
#-------
# known and unknown - determine the unknown files
# approach: each section in the makefile has a 'known' target which
# contributes to the list of known files.
# This section contains the 'unknown' target which compares the
# list of knowns to the list of files in the directory.
#-------

# Don't make the file names the same as the target names!
# name of file listing known names
KNOWN			= _known

# temporary file for this computation
KNOWN0			= _known0

# directories to check
KNOWND			= . $(PKGDATA)

known0			:
			@rm -f $(KNOWN)

known			::
			@ echo $(KNOWN) $(KNOWN0) >> $(KNOWN)	\
			; for d in $(KNOWND)			\
			; do	echo $$d/. $$d/..		\
			; done >> $(KNOWN)

unknown			: known0 known
			@ mv $(KNOWN) $(KNOWN0)			\
			; tr '\040' '\012' < $(KNOWN0)       |	\
			    sed -e '/^$$/d' -e 's:^\./::'    |	\
			    sort > $(KNOWN)			\
			; sort -u $(KNOWN) > $(KNOWN0)		\
			; if	cmp -s $(KNOWN) $(KNOWN0)	\
			; then	:				\
			; else	echo DUPS:			\
			;	comm -23 $(KNOWN) $(KNOWN0)	\
			; fi					\
			; echo UNKNOWNS:			\
			; for d in $(KNOWND)			\
			; do	ls -a $$d | sed "s:^:$$d/:"	\
			; done | sed 's:^\./::' | sort |	\
			    comm -23 - $(KNOWN)			\
			; rm -f $(KNOWN) $(KNOWN0)		\
			; exit 0

clean			::
			rm -f $(KNOWN)
			rm -f $(KNOWN0)


######################################################################
#-------
# Here we enumerate various header files
#-------

Incs			= \
			$(Cincs) \
			$(Fincs)

Cincs			= \
			areacm.h \
			comm_maaa.h \
			gcmcidas.h \
			ma.h \
			maa.h \
			ma_commDoc.h \
			maa_commDoc.h \
			maaa.h \
			toks.h

Fincs			= 

known			::
			@echo $(Incs) >> $(KNOWN)

chksrc			::
			@set X $(Incs); shift; $(CHKSRC)

uninstall.inc		::
			cd $(INCDIR) && rm -f $(Incs)

install.inc		:: chkgen uninstall.inc
			$(LN) $(Incs) $(INCDIR)
# Note: no chmod of source files (should be mode $(LIBPERM))

######################################################################
#-------
# Here we enumerate various known required files
# We require that they exist, and of course do not remove them.
#-------

MAKESTUFF		= makefile

known			::
			@echo $(MAKESTUFF) >> $(KNOWN)

chksrc			::
			@set X $(MAKESTUFF); shift; $(CHKSRC)

######################################################################
#-------
# Here we enumerate various known generated files
# We clean these up, but do not require that they exist.
#-------

MAKELOG			= makelog

known			::
			@echo $(MAKELOG) >> $(KNOWN)

clobber			::
			rm -f $(MAKELOG)

#-------
# Create executables from shell scripts needed for compiling
#-------

#coSh_Src		= \
#			mccomp.sh

#coSh_Prog		= \
#			$(MCCOMP)

#cosh_prog		: $(coSh_Prog)
#
#$(MCCOMP)		: mccomp.sh
#			rm -f $@; cp $@.sh $@; chmod $(PROGPERM) $@

#known			::
#			@echo $(coSh_Srcs) $(coSh_Prog) >> $(KNOWN)

#chksrc			::
#			@set X $(coSh_Srcs); shift; $(CHKSRC)

#clobber			:: clean
#			rm -f $(coSh_Prog)

#chkgen			::
#			@set X $(coSh_Prog); shift; $(CHKGEN)


######################################################################
#-------
# Create executables from shell scripts
#-------
#
#Sh_Srcs			= \
#			nexread.csh
#
#Sh_Prog			= \
#			nexread
#
#sh_prog			: $(Sh_Prog)
#
#nexread			: nexread.csh
#			rm -f $@; cp $@.csh $@; chmod $(PROGPERM) $@
#
#known			::
#			@echo $(Sh_Srcs) $(Sh_Prog) >> $(KNOWN)
#
#chksrc			::
#			@set X $(Sh_Srcs); shift; $(CHKSRC)
#
#clobber			:: clean
#			rm -f $(Sh_Prog)
#
#chkgen			::
#			@set X $(Sh_Prog); shift; $(CHKGEN)
#
#uninstall.bin		::
#			cd $(BINDIR) && rm -f $(Sh_Prog)
#
#install.bin		:: chkgen uninstall.bin
#			$(LN) $(Sh_Prog) $(BINDIR)
#			cd $(BINDIR) && chmod $(PROGPERM) $(Sh_Prog)
#
######################################################################
#-------
# env - this target makes sure that all the required environment
# variables are set.
#
# This target does NOT, however, do much checking to make sure that the
# contents of the variables is valid.
# This target would be the appropriate place to add such
# checks, however.
#
# _EnvList	a list of the names of the environment variables to
#		check for.
#
# _DirList	a list of the names of the directories to
#		check for.
#
# The code checks and reports ALL required but unset variables,
# rather than dying at the first one.  This helps reduce the amount
# of iteration people go through when they're setting up their
# environment.
#-------

_EnvList	= \
		McINST_ROOT

_DirList	= \
		$(McINST_ROOT)		\
		$(BINDIR)		\
		$(LIBDIR)		\
		$(INCDIR)		\
		$(DATADIR)		\
		$(HELPDIR)

_EnvMesg	= $(MAKE): ERROR: environment variable not set:
_DirMesg	= $(MAKE): ERROR: no directory:
_DirHelp	= $(MAKE): If your environment is OK, try "'make rootdirs'"
_LocMesg	= $(MAKE): ERROR: cannot put package source here:

env		: env_var env_dir

env_var		:
		@ exit=0					\
		; for v in $(_EnvList)				\
		; do	eval "	case \$$$$v in			\
				'')	echo $(_EnvMesg) $$v;	\
					exit=1;;		\
				esac"				\
		; done						\
		; exit $$exit

env_dir		:
		@ exit=0					\
		; for v in $(_DirList)				\
		; do	if	[ ! -d "$$v" ]			\
		;	then	echo $(_DirMesg) $$v		\
		;		exit=1				\
		;	fi					\
		; done						\
		; case $$exit in				\
		  0)	;;					\
		  *)	echo $(_DirHelp);;			\
		  esac						\
		; pwd=`pwd`					\
		; for v in $(_DirList)				\
		; do	case $$v in				\
			$$pwd)	echo $(_LocMesg) $$v;		\
				exit=1;;			\
			esac					\
		; done						\
		; exit $$exit

rootdirs	: env_var
		@ exit=0					\
		; for v in $(_DirList)				\
		; do	if	[ ! -d "$$v" ]			\
		;	then	echo	mkdir $$v		\
		;			mkdir $$v		\
		;	fi					\
		; done						\
		; exit $$exit


######################################################################
#-------
# Top-level targets for libmcrd.
#-------

LIBMcRD			= libmcrd.a

_all			:: $(LIBMcRD)

chkgen			::
			@set X $(LIBMcRD); shift; $(CHKGEN)

known			::
			@echo $(LIBMcRD) >> $(KNOWN)

clobber			::
			rm -f $(LIBMcRD)

uninstall.lib		::
			cd $(LIBDIR) && rm -f $(LIBMcRD)

install.lib		:: chkgen uninstall.lib
			$(LN) $(LIBMcRD) $(LIBDIR)
			cd $(LIBDIR) && chmod $(LIBPERM) $(LIBMcRD)

######################################################################
#-------
# These are programs which require libmcidas to build and which may
# have multiple source files.
#
# Note that macro3 must be built before we can compile the macros.
#-------

macro3			= macro3
macro3_srcs		= macro3.fp
macro3_objs		= macro3.o

$(macro3)		: $(macro3_objs) $(LIBDEPS)
			@$(LFP) -o $@ $(macro3_objs) $(LIBARGS)

Fp2_Prog		= \
			$(macro3)

Fp2_Srcs		= \
			$(macro3_srcs)

Fp2_Objs		= \
			$(macro3_objs)

_all			:: $(Fp2_Prog)

chksrc			::
			@set X $(Fp2_Srcs); shift; $(CHKSRC)

chkgen			::
			@set X $(Fp2_Prog); shift; $(CHKGEN)

known			::
			@echo $(Fp2_Srcs) >> $(KNOWN)
			@echo $(Fp2_Objs) >> $(KNOWN)
			@echo $(Fp2_Prog) >> $(KNOWN)

clean			::
			rm -f $(Fp2_Objs)

clobber			:: clean
			rm -f $(Fp2_Prog)

uninstall.bin		::
			cd $(BINDIR) && rm -f $(Fp2_Prog)

install.bin		:: chkgen uninstall.bin
			$(LN) $(Fp2_Prog) $(BINDIR)
			cd $(BINDIR) && chmod $(PROGPERM) $(Fp2_Prog)

######################################################################
#-------
# C sources for libmcidas.
#-------

LIBMcRD_C1SRCS		= \
			circutil.c \
			ftops_.c \
			io.c \
			j1getsigmet_.c \
			j2getsigmet_.c \
			mautil.c \
			maautil.c \
			maaautil.c \
			toks.c 

LIBMcRD_C1OBJS		= $(LIBMcRD_C1SRCS:.c=.o)

$(LIBMcRD)		:: $(LIBMcRD_C1OBJS)
			@$(MCLOG) $(MCAR) $(LIBMcRD) $?

chksrc			::
			@set X $(LIBMcRD_C1SRCS); shift; $(CHKSRC)

known			::
			@echo $(LIBMcRD_C1SRCS) >> $(KNOWN)
			@echo $(LIBMcRD_C1OBJS) >> $(KNOWN)

clean			::
			rm -f $(LIBMcRD_C1OBJS)

######################################################################
#-------
# Fortran sources for libmcidas.
#-------
#
#LIBMcRD_F1SRCS	=
#
#LIBMcRD_F1OBJS	= 	$(LIBMcRD_F1SRCS:.for=.o)
#
#$(LIBMcRD)		:: $(LIBMcRD_F1OBJS)
#			@$(MCLOG) $(MCAR) $(LIBMcRD) $?
#
#chksrc			::
#			@set X $(LIBMcRD_F1SRCS); shift; $(CHKSRC)
#
#known			::
#			@echo $(LIBMcRD_F1SRCS) >> $(KNOWN)
#			@echo $(LIBMcRD_F1OBJS) >> $(KNOWN)
#
#clean			::
#			rm -f $(LIBMcRD_F1OBJS)
#
######################################################################
#-------
# Fortran sources for libmcidas.
#
# These are files that nothing in core mcidas uses, but which need to
# be in libmcidas.a for the sake of other packages.
#-------

LIBMcRD_UF1SRCS		= \
			decsubs.for \
			getaws.for \
			j1adv_info.for \
			j1xsymb.for \
			j1compas.for \
			m0parobs.for \
			m0tirdec.for \
			mcextrln.for \
			omtpadir2.for \
			omtpaget2.for \
			pltvec.for \
			pref_bndlist.for \
			sortfram.for \
			ts_utils.for

LIBMcRD_UF1OBJS	= 	$(LIBMcRD_UF1SRCS:.for=.o)

$(LIBMcRD)		:: $(LIBMcRD_UF1OBJS)
			@$(MCLOG) $(MCAR) $(LIBMcRD) $?

chksrc			::
			@set X $(LIBMcRD_UF1SRCS); shift; $(CHKSRC)

known			::
			@echo $(LIBMcRD_UF1SRCS) >> $(KNOWN)
			@echo $(LIBMcRD_UF1OBJS) >> $(KNOWN)

clean			::
			rm -f $(LIBMcRD_UF1OBJS)

######################################################################
#-------
# Fortran mdx dynamic load modules for libmcrd.
#-------

#Dlm1_Srcs		= \
#			mdxgra.dlm
#
#Dlm1_Gens		= 
#			mdxgra.f \
#
#Dlm1_Objs		= $(Dlm1_Gens:.f=.o)
#
#
#$(LIBMcRD)		:: $(Dlm1_Objs)
#			@$(MCLOG) $(MCAR) $(LIBMcRD) $?
#
#mdxgra.f		: $(convdlm) mdxgra.dlm
#			@ $(CONVCMD) mdxgra.dlm
#mdxgrd.f		: $(convdlm) mdxgrd.dlm
#			@ $(CONVCMD) mdxgrd.dlm
#mdxint.f		: $(convdlm) mdxint.dlm
#			@ $(CONVCMD) mdxint.dlm
#mdxmd.f			: $(convdlm) mdxmd.dlm
#			@ $(CONVCMD) mdxmd.dlm
#mdxop.f			: $(convdlm) mdxop.dlm
#			@ $(CONVCMD) mdxop.dlm
#mdxpri.f		: $(convdlm) mdxpri.dlm
#			@ $(CONVCMD) mdxpri.dlm
#
#chksrc			::
#			@set X $(Dlm1_Srcs); shift; $(CHKSRC)
#
#known			::
#			@echo $(Dlm1_Srcs) >> $(KNOWN)
#			@echo $(Dlm1_Gens) >> $(KNOWN)
#			@echo $(Dlm1_Objs) >> $(KNOWN)
#
#clean			::
#			rm -f $(Dlm1_Gens)
#			rm -f $(Dlm1_Objs)
#
######################################################################
#-------
# Fortran kbx & nvx dynamic load modules for libmcidas.
#-------
#
#Dlm3_Srcs		= \
#			kbxaaa.dlm	\
#
#Dlm3_Gens     = \
#	kb1aaa.f	kb2aaa.f	kb3aaa.f	\
#
#Dlm3_Objs		= $(Dlm3_Gens:.f=.o)
#
#
#$(LIBMcRD)		:: $(Dlm3_Objs)
#			@$(MCLOG) $(MCAR) $(LIBMcRD) $?
#
#
#kb1aaa.f	kb2aaa.f	kb3aaa.f	: $(convdlm) kbxaaa.dlm
#						@ $(CONVCMD) kbxaaa.dlm
#
#chksrc			::
#			@set X $(Dlm3_Srcs); shift; $(CHKSRC)
#
#known			::
#			@echo $(Dlm3_Srcs) >> $(KNOWN)
#			@echo $(Dlm3_Gens) >> $(KNOWN)
#			@echo $(Dlm3_Objs) >> $(KNOWN)
#
#clean			::
#			rm -f $(Dlm3_Gens)
#			rm -f $(Dlm3_Objs)
#
######################################################################

######################################################################
#-------
# Utility macros for linking .k programs.
#
# These are defined down here so as to be closer to the part of the
# makefile that uses them.
#-------

LIBDEPS			= $(LIBMcIDAS) $(LIBMcRD)
LIBARGS			= -L. -L$(McLIB) -lmcrd -lmcidas

XLIBDEPS		= $(LIBMcIDAS)
XLIBARGS		= -L. -L$(McLIB) -lmcidas -lXext -lX11

XTLIBDEPS		= $(LIBMcIDAS)
XTLIBARGS		= -L. -L$(McLIB) -lmcidas -lXt -lX11

MXLIBDEPS		= $(LIBMcIDAS)
MXLIBARGS		= -L. -L$(McLIB) -lmcidas -lXm -lXt -lX11

main_o			= $(McLIB)/main.o

######################################################################

######################################################################
#-------
# McIDAS keyins from macros
#-------

Mac_Srcs		= \
			imgdispcp.mac   \
			sc.mac          \
			sp.mac          \
			uc.mac          \
			up.mac

Mac_Objs		= $(Mac_Srcs:.mac=.o)

Mac_Prog		= $(Mac_Srcs:.mac=.k)

Mac_Help		= $(Mac_Srcs:.mac=.hlp)

$(Mac_Objs)		: $(macro3)

imgdispcp.k		: $(main_o) imgdispcp.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) imgdispcp.o $(LIBARGS)

sc.k			: $(main_o) sc.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) sc.o $(LIBARGS)

sp.k			: $(main_o) sp.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) sp.o $(LIBARGS)

uc.k			: $(main_o) uc.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) uc.o $(LIBARGS)

up.k			: $(main_o) up.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) up.o $(LIBARGS)

_all			:: $(Mac_Prog) $(Mac_Help)

chksrc			::
			@set X $(Mac_Srcs); shift; $(CHKSRC)

chkgen			::
			@set X $(Mac_Prog); shift; $(CHKGEN)
			@set X $(Mac_Help); shift; $(CHKGEN)

known			::
			@echo $(Mac_Srcs) >> $(KNOWN)
			@echo $(Mac_Objs) >> $(KNOWN)
			@echo $(Mac_Prog) >> $(KNOWN)
			@echo $(Mac_Help) >> $(KNOWN)

clean			::
			rm -f $(Mac_Objs)

clobber			:: clean
			rm -f $(Mac_Prog)
			rm -f $(Mac_Help)

uninstall.bin		::
			cd $(BINDIR) && rm -f $(Mac_Prog)

install.bin		:: chkgen uninstall.bin
			$(LN) $(Mac_Prog) $(BINDIR)
			cd $(BINDIR) && chmod $(PROGPERM) $(Mac_Prog)

uninstall.help		::
			cd $(HELPDIR) && rm -f $(Mac_Help)

install.help		:: chkgen uninstall.help
			$(LN) $(Mac_Help) $(HELPDIR)
			cd $(HELPDIR) && chmod $(RODATAPERM) $(Mac_Help)
######################################################################

######################################################################
#-------
# McIDAS keyins from single .c files
#-------

Cpgm_Srcs		= \
			convert_lev1b.c \
			imgfloat.c \
			timeinc.c \
			tnavdec.c

Cpgm_Objs		= $(Cpgm_Srcs:.c=.o)

Cpgm_Prog		= $(Cpgm_Srcs:.c=.k)

Cpgm_Help		= $(Cpgm_Srcs:.c=.hlp)

convert_lev1b.k		: convert_lev1b.o $(LIBDEPS)
			@$(L) -o $@ convert_lev1b.o $(LIBARGS)

imgfloat.k		: imgfloat.o $(LIBDEPS)
			@$(L) -o $@ imgfloat.o $(LIBARGS)

timeinc.k		: timeinc.o $(LIBDEPS)
			@$(L) -o $@ timeinc.o $(LIBARGS)

tnavdec.k		: tnavdec.o $(LIBDEPS)
			@$(L) -o $@ tnavdec.o $(LIBARGS)

_all			:: $(Cpgm_Prog) $(Cpgm_Help)

chksrc			::
			@set X $(Cpgm_Srcs); shift; $(CHKSRC)

chkgen			::
			@set X $(Cpgm_Prog); shift; $(CHKGEN)
			@set X $(Cpgm_Help); shift; $(CHKGEN)

known			::
			@echo $(Cpgm_Srcs) >> $(KNOWN)
			@echo $(Cpgm_Objs) >> $(KNOWN)
			@echo $(Cpgm_Prog) >> $(KNOWN)
			@echo $(Cpgm_Help) >> $(KNOWN)

clean			::
			rm -f $(Cpgm_Objs)

clobber			:: clean
			rm -f $(Cpgm_Prog)
			rm -f $(Cpgm_Help)

uninstall.bin		::
			cd $(BINDIR) && rm -f $(Cpgm_Prog)

install.bin		:: chkgen uninstall.bin
			$(LN) $(Cpgm_Prog) $(BINDIR)
			cd $(BINDIR) && chmod $(PROGPERM) $(Cpgm_Prog)

uninstall.help		::
			cd $(HELPDIR) && rm -f $(Cpgm_Help)

install.help		:: chkgen uninstall.help
			$(LN) $(Cpgm_Help) $(HELPDIR)
			cd $(HELPDIR) && chmod $(RODATAPERM) $(Cpgm_Help)

######################################################################
#-------
# McIDAS keyins requiring Motif
#-------
#
#ask1			= ask1.k
#ask1_srcs		= ask1.c
#ask1_objs		= ask1.o
#ask1_help		= ask1.hlp
#
#$(ask1)			: $(ask1_objs) $(MXLIBDEPS)
#			@$(L) -o $@ $(ask1_objs) $(MXLIBARGS)
#
#Motif_Srcs		= \
#			$(ask1_srcs)
#
#Motif_Objs		= \
#			$(ask1_objs)
#
#Motif_Prog		= \
#			$(ask1)
#
#Motif_Help		= \
#			$(ask1_help)
#
#
#_all			:: $(Motif_Prog) $(Motif_Help)
#
#chksrc			::
#			@set X $(Motif_Srcs); shift; $(CHKSRC)
#
#chkgen			::
#			@set X $(Motif_Prog); shift; $(CHKGEN)
#			@set X $(Motif_Help); shift; $(CHKGEN)
#
#known			::
#			@echo $(Motif_Srcs) >> $(KNOWN)
#			@echo $(Motif_Objs) >> $(KNOWN)
#			@echo $(Motif_Prog) >> $(KNOWN)
#			@echo $(Motif_Help) >> $(KNOWN)
#
#clean			::
#			rm -f $(Motif_Objs)
#
#clobber			:: clean
#			rm -f $(Motif_Prog)
#			rm -f $(Motif_Help)
#
#uninstall.bin		::
#			cd $(BINDIR) && rm -f $(Motif_Prog)
#
#install.bin		:: chkgen uninstall.bin
#			$(LN) $(Motif_Prog) $(BINDIR)
#			cd $(BINDIR) && chmod $(PROGPERM) $(Motif_Prog)
#
#uninstall.help		::
#			cd $(HELPDIR) && rm -f $(Motif_Help)
#
#install.help		:: chkgen uninstall.help
#			$(LN) $(Motif_Help) $(HELPDIR)
#			cd $(HELPDIR) && chmod $(RODATAPERM) $(Motif_Help)

######################################################################
#-------
# system executables (non-.k)
#-------

Sys_Srcs		= \
			airxadir.cp \
			airxaget.cp \
			amrradir.cp \
			amrraget.cp \
			amseadir.cp \
			amseaget.cp \
			amsradir.cp \
			amsraget.cp \
			ashxadir.cp \
			ashxaget.cp \
			awipadir.cp \
			awipaget.cp \
			awipaput.cp \
			catgadir.cp \
			catgaget.cp \
			bufrks.cp \
			kalpadir.cp \
			kalpaget.cp \
			maadir.cp \
			maaget.cp \
			maaadir.cp \
			maaaget.cp \
			maaaadir.cp \
			maaaaget.cp \
			mod3adir.cp \
			mod3aget.cp \
			modcadir.cp \
			modcaget.cp \
			modiadir.cp \
			modiaget.cp \
			modladir.cp \
			modlaget.cp \
			modvadir.cp \
			modvaget.cp \
			nssxadir.cp \
			nssxaget.cp \
			omtpadir.cp \
			omtpaget.cp \
			sminadir.cp \
			sminaget.cp \
			tminadir.cp \
			tminaget.cp 

Sys_Objs		= $(Sys_Srcs:.cp=.o)

Sys_Prog		= $(Sys_Srcs:.cp=)

airxadir		: airxadir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ airxadir.o $(SDILIBARGS) $(HDFLIBARGS)
airxaget		: airxaget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ airxaget.o $(SDILIBARGS) $(HDFLIBARGS)
amrradir		: amrradir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ amrradir.o $(SDILIBARGS) $(HDFLIBARGS)
amrraget		: amrraget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ amrraget.o $(SDILIBARGS) $(HDFLIBARGS)
amseadir		: amseadir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ amseadir.o $(SDILIBARGS) $(HDFLIBARGS)
amseaget		: amseaget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ amseaget.o $(SDILIBARGS) $(HDFLIBARGS)
ashxadir		: ashxadir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ ashxadir.o $(SDILIBARGS) $(HDFLIBARGS)
ashxaget		: ashxaget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ ashxaget.o $(SDILIBARGS) $(HDFLIBARGS)
amsradir		: amsradir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ amsradir.o $(SDILIBARGS) $(HDFLIBARGS)
amsraget		: amsraget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ amsraget.o $(SDILIBARGS) $(HDFLIBARGS)
awipadir		: awipadir.o $(SDILIBDEPS) $(NCDFLIBDEPS)
		@$(L) -o $@ awipadir.o $(SDILIBARGS) $(NCDFLIBARGS)
awipaget		: awipaget.o $(SDILIBDEPS) $(NCDFLIBDEPS)
		@$(L) -o $@ awipaget.o $(SDILIBARGS) $(NCDFLIBARGS)
awipaput		: awipaput.o $(SDILIBDEPS) $(NCDFLIBDEPS)
		@$(L) -o $@ awipaput.o $(SDILIBARGS) $(NCDFLIBARGS)
bufrks			: bufrks.o $(SDILIBDEPS) $(HDFLIBDEPS) $(NCDFLIBDEPS)
		@$(L) -o $@ bufrks.o $(SDILIBARGS) $(HDFLIBARGS) $(NCDFLIBARGS)
catgadir		: catgadir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ catgadir.o $(SDILIBARGS) $(HDFLIBARGS)
catgaget		: catgaget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ catgaget.o $(SDILIBARGS) $(HDFLIBARGS)
kalpadir		: kalpadir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ kalpadir.o $(SDILIBARGS) $(HDFLIBARGS)
kalpaget		: kalpaget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ kalpaget.o $(SDILIBARGS) $(HDFLIBARGS)
maadir			: maadir.o $(LIBDEPS) $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ maadir.o $(LIBDEPS) $(SDILIBARGS) $(HDFLIBARGS)
maaget			: maaget.o $(LIBDEPS) $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ maaget.o $(LIBDEPS) $(SDILIBARGS) $(HDFLIBARGS)
maaadir			: maaadir.o $(LIBDEPS) $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ maaadir.o $(LIBDEPS) $(SDILIBARGS) $(HDFLIBARGS)
maaaget			: maaaget.o $(LIBDEPS) $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ maaaget.o $(LIBDEPS) $(SDILIBARGS) $(HDFLIBARGS)
maaaadir		: maaaadir.o $(LIBDEPS) $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ maaaadir.o $(LIBDEPS) $(SDILIBARGS) $(HDFLIBARGS)
maaaaget		: maaaaget.o $(LIBDEPS) $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ maaaaget.o $(LIBDEPS) $(SDILIBARGS) $(HDFLIBARGS)
mod3adir		: mod3adir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ mod3adir.o $(SDILIBARGS) $(HDFLIBARGS)
mod3aget		: mod3aget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ mod3aget.o $(SDILIBARGS) $(HDFLIBARGS)
modcadir		: modcadir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ modcadir.o $(SDILIBARGS) $(HDFLIBARGS)
modcaget		: modcaget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ modcaget.o $(SDILIBARGS) $(HDFLIBARGS)
modiadir		: modiadir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ modiadir.o $(SDILIBARGS) $(HDFLIBARGS)
modiaget		: modiaget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ modiaget.o $(SDILIBARGS) $(HDFLIBARGS)
modladir		: modladir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ modladir.o $(SDILIBARGS) $(HDFLIBARGS)
modlaget		: modlaget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ modlaget.o $(SDILIBARGS) $(HDFLIBARGS)
modvadir		: modvadir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ modvadir.o $(SDILIBARGS) $(HDFLIBARGS)
modvaget		: modvaget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ modlaget.o $(SDILIBARGS) $(HDFLIBARGS)
nssxadir		: nssxadir.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ nssxadir.o $(SDILIBARGS) $(HDFLIBARGS)
nssxaget		: nssxaget.o $(SDILIBDEPS) $(HDFLIBDEPS)
		@$(L) -o $@ nssxaget.o $(SDILIBARGS) $(HDFLIBARGS)
omtpadir		: omtpadir.o $(LIBDEPS) $(SDILIBDEPS) $(NCDFLIBDEPS)
		@$(L) -o $@ omtpadir.o $(LIBDEPS) $(SDILIBARGS) $(NCDFLIBARGS)
omtpaget		: omtpaget.o $(LIBDEPS) $(SDILIBDEPS) $(NCDFLIBDEPS)
		@$(L) -o $@ omtpaget.o $(LIBDEPS) $(SDILIBARGS) $(NCDFLIBARGS)
sminadir		: sminadir.o $(SDILIBDEPS) $(NCDFLIBDEPS)
		@$(L) -o $@ sminadir.o $(SDILIBARGS) $(NCDFLIBARGS)
sminaget		: sminaget.o $(SDILIBDEPS) $(NCDFLIBDEPS)
		@$(L) -o $@ sminaget.o $(SDILIBARGS) $(NCDFLIBARGS)
tminadir		: tminadir.o $(SDILIBDEPS) $(NCDFLIBDEPS)
		@$(L) -o $@ tminadir.o $(SDILIBARGS) $(NCDFLIBARGS)
tminaget		: tminaget.o $(SDILIBDEPS) $(NCDFLIBDEPS)
		@$(L) -o $@ tminaget.o $(SDILIBARGS) $(NCDFLIBARGS)

_all			:: $(Sys_Prog)

chksrc			::
			@set X $(Sys_Srcs); shift; $(CHKSRC)

chkgen			::
			@set X $(Sys_Prog); shift; $(CHKGEN)

known			::
			@echo $(Sys_Srcs) >> $(KNOWN)
			@echo $(Sys_Objs) >> $(KNOWN)
			@echo $(Sys_Prog) >> $(KNOWN)

clean			::
			rm -f $(Sys_Objs)

clobber			:: clean
			rm -f $(Sys_Prog)

uninstall.bin		::
			cd $(BINDIR) && rm -f $(Sys_Prog)

install.bin		:: chkgen uninstall.bin
			$(LN) $(Sys_Prog) $(BINDIR)
			cd $(BINDIR) && chmod $(PROGPERM) $(Sys_Prog)
#######################################################################
#-------
# Non-McIDAS FP's
#-------
#
#SERVDEPS		= $(LIBMcIDAS) $(LIBMcRD)
#SERVARGS		= -L. $(McLIB) -lmcrd -lmcidas
#
#
#Fp3_Srcs		= \
#			adelserv.fp
#
#Fp3_Objs		= $(Fp3_Srcs:.fp=.o)
#
#Fp3_Prog		= $(Fp3_Srcs:.fp=)
#
#adelserv		: adelserv.o $(SERVDEPS)
#			@$(LFP) -o $@ adelserv.o $(SERVARGS)
#
#_all			:: $(Fp3_Prog)
#
#chksrc			::
#			@set X $(Fp3_Srcs); shift; $(CHKSRC)
#
#chkgen			::
#			@set X $(Fp3_Prog); shift; $(CHKGEN)
#
#known			::
#			@echo $(Fp3_Srcs) >> $(KNOWN)
#			@echo $(Fp3_Objs) >> $(KNOWN)
#			@echo $(Fp3_Prog) >> $(KNOWN)
#
#clean			::
#			rm -f $(Fp3_Objs)
#
#clobber			:: clean
#			rm -f $(Fp3_Prog)
#
#uninstall.bin		::
#			cd $(BINDIR) && rm -f $(Fp3_Prog)
#
#install.bin		:: chkgen uninstall.bin
#			$(LN) $(Fp3_Prog) $(BINDIR)
#			cd $(BINDIR) && chmod $(PROGPERM) $(Fp3_Prog)
#
# Note: no chmod of source files (should be mode $(RODATAPERM))

######################################################################
#-------
# McIDAS keyins from single .pgm files
#-------

LIBU77			= U77
Pgm_Srcs		= \
			abba.pgm \
			advdisp.pgm \
			angles.pgm \
			astat.pgm \
			awslapse_ts.pgm \
			awsloc.pgm \
			awsmg.pgm \
			awsp_ts.pgm \
			barcp.pgm \
			beep.pgm \
			binnav.pgm \
			canrad.pgm \
			catomtp.pgm \
			changecal.pgm \
			circle.pgm \
			cldtopo.pgm \
			cloudh.pgm \
			colimgplot.pgm \
			comp_allband.pgm \
			compgg.pgm \
			compmg.pgm \
			compmm.pgm \
			crasimg.pgm \
			dirlist.pgm \
			fcstcon.pgm \
			fcstplot.pgm \
			filter.pgm \
			fixfy2d_nav2012.pgm \
			fixgribid.pgm \
			fixraw.pgm \
			front.pgm \
			frontpth.pgm \
			getcomposites.pgm \
			getdmsp.pgm \
			getgac.pgm \
			gethrpt.pgm \
			get_point_sfc.pgm \
			gvarinfo.pgm \
			gvva.pgm \
			ifr.pgm \
			igtv.pgm \
			imgcombo.pgm \
			imggra.pgm \
			imggrd.pgm \
			imgmake.pgm \
			imgnorm.pgm \
			imgparm.pgm \
			imgproc.pgm \
			irt.pgm \
			limbfit.pgm \
			llbox.pgm \
			make_multib.pgm \
			makeimg.pgm \
			makemap.pgm \
			maketopo.pgm \
			map2text.pgm \
			mcawips.pgm \
			mddpi.pgm \
			mdscat.pgm \
			merge_geo.pgm \
			merge_goes.pgm \
			merge_goesns.pgm \
			merge_polar.pgm \
			mgxs.pgm \
			moslist.pgm \
			navpass.pgm \
			nd.pgm \
			nexrad.pgm \
			nk.pgm \
			nl.pgm \
			nm.pgm \
			nortel.pgm \
			nowcast.pgm \
			nvu.pgm \
			oldsvf.pgm \
			path.pgm \
			pirpplot.pgm \
			poescal.pgm \
			pred.pgm \
			proplt.pgm \
			radar.pgm \
			rain.pgm \
			remap2.pgm \
			roadmap.pgm \
			rotiro.pgm \
			rmrtmdg.pgm \
			satcomp.pgm \
			sfctime.pgm \
			smooft.pgm \
			stg.pgm \
			stndev.pgm \
			svga.pgm \
			svps.pgm \
			taflist.pgm \
			thpass.pgm \
			tirchk.pgm \
			tlpass.pgm \
			tordec.pgm \
			tordisp.pgm \
			torlist.pgm \
			txt2msg.pgm \
			txtnav.pgm \
			when.pgm \
			windbox.pgm \
			windflag.pgm \
			wrtext.pgm \
			wuus.pgm \
			wxsdith.pgm \
			xfgrid.pgm \
			xsectg.pgm \
			zfp.pgm 

Pgm_Objs		= $(Pgm_Srcs:.pgm=.o)

Pgm_Prog		= $(Pgm_Srcs:.pgm=.k)

Pgm_Help		= $(Pgm_Srcs:.pgm=.hlp)

abba.k			: $(main_o) abba.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) abba.o $(LIBARGS)
advdisp.k		: $(main_o) advdisp.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) advdisp.o $(LIBARGS)
angles.k		: $(main_o) angles.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) angles.o $(LIBARGS)
astat.k			: $(main_o) astat.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) astat.o $(LIBARGS)
awsarcdec.k		: $(main_o) awsarcdec.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) awsarcdec.o $(LIBARGS)
awslapse_ts.k		: $(main_o) awslapse_ts.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) awslapse_ts.o $(LIBARGS)
awsloc.k		: $(main_o) awsloc.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) awsloc.o $(LIBARGS)
awsmg.k			: $(main_o) awsmg.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) awsmg.o $(LIBARGS)
awsp_ts.k		: $(main_o) awsp_ts.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) awsp_ts.o $(LIBARGS)
barcp.k			: $(main_o) barcp.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) barcp.o $(LIBARGS)
beep.k			: $(main_o) beep.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) beep.o $(LIBARGS)
binnav.k		: $(main_o) binnav.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) binnav.o $(LIBARGS)
canrad.k		: $(main_o) canrad.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) canrad.o $(LIBARGS)
catomtp.k		: $(main_o) catomtp.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) catomtp.o $(LIBARGS)
changecal.k		: $(main_o) changecal.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) changecal.o $(LIBARGS)
circle.k		: $(main_o) circle.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) circle.o $(LIBARGS)
cldtopo.k		: $(main_o) cldtopo.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) cldtopo.o $(LIBARGS)
cloudh.k		: $(main_o) cloudh.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) cloudh.o $(LIBARGS)
colimgplot.k		: $(main_o) colimgplot.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) colimgplot.o $(LIBARGS)
comp_allband.k		: $(main_o) comp_allband.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) comp_allband.o $(LIBARGS)
compgg.k		: $(main_o) compgg.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) compgg.o $(LIBARGS)
compmg.k		: $(main_o) compmg.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) compmg.o $(LIBARGS)
compmm.k		: $(main_o) compmm.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) compmm.o $(LIBARGS)
conpass.k		: $(main_o) conpass.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) conpass.o $(LIBARGS)
crasimg.k		: $(main_o) crasimg.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) crasimg.o $(LIBARGS)
dirlist.k		: $(main_o) dirlist.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) dirlist.o $(LIBARGS)
fcstcon.k		: $(main_o) fcstcon.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) fcstcon.o $(LIBARGS)
fcstplot.k		: $(main_o) fcstplot.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) fcstplot.o $(LIBARGS)
filter.k		: $(main_o) filter.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) filter.o $(LIBARGS)
fixfy2d_nav2012.k	: $(main_o) fixfy2d_nav2012.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) fixfy2d_nav2012.o $(LIBARGS)
fixgribid.k		: $(main_o) fixgribid.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) fixgribid.o $(LIBARGS)
fixraw.k		: $(main_o) fixraw.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) fixraw.o $(LIBARGS)
front.k			: $(main_o) front.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) front.o $(LIBARGS)
frontpth.k		: $(main_o) frontpth.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) frontpth.o $(LIBARGS)
getcomposites.k		: $(main_o) getcomposites.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) getcomposites.o $(LIBARGS)
getdmsp.k		: $(main_o) getdmsp.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) getdmsp.o $(LIBARGS)
getgac.k		: $(main_o) getgac.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) getgac.o $(LIBARGS)
gethrpt.k		: $(main_o) gethrpt.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) gethrpt.o $(LIBARGS)
get_point_sfc.k		: $(main_o) get_point_sfc.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) get_point_sfc.o $(LIBARGS)
gvarinfo.k		: $(main_o) gvarinfo.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) gvarinfo.o $(LIBARGS)
gvva.k			: $(main_o) gvva.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) gvva.o $(LIBARGS)
ifr.k			: $(main_o) ifr.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) ifr.o $(LIBARGS)
igtv.k			: $(main_o) igtv.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) igtv.o $(LIBARGS)
imgcombo.k		: $(main_o) imgcombo.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) imgcombo.o $(LIBARGS)
imggra.k		: $(main_o) imggra.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) imggra.o $(LIBARGS)
imggrd.k		: $(main_o) imggrd.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) imggrd.o $(LIBARGS)
imgmake.k		: $(main_o) imgmake.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) imgmake.o $(LIBARGS)
imgnorm.k		: $(main_o) imgnorm.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) imgnorm.o $(LIBARGS)
imgparm.k		: $(main_o) imgparm.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) imgparm.o $(LIBARGS)
imgproc.k		: $(main_o) imgproc.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) imgproc.o $(LIBARGS)
irt.k			: $(main_o) irt.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) irt.o $(LIBARGS)
limbfit.k		: $(main_o) limbfit.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) limbfit.o $(LIBARGS)
llbox.k			: $(main_o) llbox.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) llbox.o $(LIBARGS)
make_multib.k		: $(main_o) make_multib.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) make_multib.o $(LIBARGS)
makeimg.k		: $(main_o) makeimg.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) makeimg.o $(LIBARGS)
makemap.k		: $(main_o) makemap.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) makemap.o $(LIBARGS)
maketopo.k		: $(main_o) maketopo.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) maketopo.o $(LIBARGS)
map2text.k		: $(main_o) map2text.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) map2text.o $(LIBARGS)
mcawips.k		: $(main_o) mcawips.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) mcawips.o $(LIBARGS)
mddpi.k			: $(main_o) mddpi.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) mddpi.o $(LIBARGS)
mdscat.k		: $(main_o) mdscat.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) mdscat.o $(LIBARGS)
merge_geo.k		: $(main_o) merge_geo.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) merge_geo.o $(LIBARGS)
merge_goes.k		: $(main_o) merge_goes.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) merge_goes.o $(LIBARGS)
merge_goesns.k		: $(main_o) merge_goesns.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) merge_goesns.o $(LIBARGS)
merge_polar.k		: $(main_o) merge_polar.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) merge_polar.o $(LIBARGS)
mgxs.k			: $(main_o) mgxs.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) mgxs.o $(LIBARGS)
moslist.k		: $(main_o) moslist.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) moslist.o $(LIBARGS)
navpass.k		: $(main_o) navpass.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) navpass.o $(LIBARGS)
nd.k			: $(main_o) nd.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) nd.o $(LIBARGS)
nexrad.k		: $(main_o) nexrad.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) nexrad.o $(LIBARGS)
nk.k			: $(main_o) nk.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) nk.o $(LIBARGS)
nl.k			: $(main_o) nl.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) nl.o $(LIBARGS)
nm.k			: $(main_o) nm.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) nm.o $(LIBARGS)
nortel.k		: $(main_o) nortel.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) nortel.o $(LIBARGS)
nowcast.k		: $(main_o) nowcast.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) nowcast.o $(LIBARGS)
nvu.k			: $(main_o) nvu.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) nvu.o $(LIBARGS)
oldsvf.k		: $(main_o) oldsvf.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) oldsvf.o $(LIBARGS)
path.k			: $(main_o) path.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) path.o $(LIBARGS)
pirpplot.k		: $(main_o) pirpplot.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) pirpplot.o $(LIBARGS)
poescal.k		: $(main_o) poescal.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) poescal.o $(LIBARGS)
pred.k			: $(main_o) pred.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) pred.o $(LIBARGS)
proplt.k		: $(main_o) proplt.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) proplt.o $(LIBARGS)
radar.k			: $(main_o) radar.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) radar.o $(LIBARGS)
rain.k			: $(main_o) rain.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) rain.o $(LIBARGS)
remap2.k		: $(main_o) remap2.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) remap2.o $(LIBARGS)
roadmap.k		: $(main_o) roadmap.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) roadmap.o $(LIBARGS)
rotiro.k		: $(main_o) rotiro.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) rotiro.o $(LIBARGS)
rmrtmdg.k		: $(main_o) rmrtmdg.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) rmrtmdg.o $(LIBARGS)
satcomp.k		: $(main_o) satcomp.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) satcomp.o $(LIBARGS)
sfctime.k		: $(main_o) sfctime.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) sfctime.o $(LIBARGS)
smooft.k		: $(main_o) smooft.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) smooft.o $(LIBARGS)
stg.k			: $(main_o) stg.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) stg.o $(LIBARGS)
stndev.k		: $(main_o) stndev.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) stndev.o $(LIBARGS)
svga.k			: $(main_o) svga.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) svga.o $(LIBARGS)
svps.k			: $(main_o) svps.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) svps.o $(LIBARGS)
taflist.k		: $(main_o) taflist.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) taflist.o $(LIBARGS)
thpass.k		: $(main_o) thpass.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) thpass.o $(LIBARGS)
tirchk.k		: $(main_o) tirchk.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) tirchk.o $(LIBARGS)
tlpass.k		: $(main_o) tlpass.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) tlpass.o $(LIBARGS)
tordec.k		: $(main_o) tordec.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) tordec.o $(LIBARGS)
tordisp.k		: $(main_o) tordisp.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) tordisp.o $(LIBARGS)
torlist.k		: $(main_o) torlist.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) torlist.o $(LIBARGS)
txt2msg.k		: $(main_o) txt2msg.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) txt2msg.o $(LIBARGS)
txtnav.k		: $(main_o) txtnav.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) txtnav.o $(LIBARGS)
when.k			: $(main_o) when.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) when.o $(LIBARGS)
windbox.k		: $(main_o) windbox.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) windbox.o $(LIBARGS)
windflag.k		: $(main_o) windflag.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) windflag.o $(LIBARGS)
wrtext.k		: $(main_o) wrtext.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) wrtext.o $(LIBARGS)
wuus.k			: $(main_o) wuus.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) wuus.o $(LIBARGS)
wxsdith.k		: $(main_o) wxsdith.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) wxsdith.o $(LIBARGS)
xfgrid.k		: $(main_o) xfgrid.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) xfgrid.o $(LIBARGS)
xsectg.k		: $(main_o) xsectg.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) xsectg.o $(LIBARGS)
zfp.k			: $(main_o) zfp.o $(LIBDEPS)
			@$(L) -o $@ $(main_o) zfp.o $(LIBARGS)


_all			:: $(Pgm_Prog) $(Pgm_Help)

chksrc			::
			@set X $(Pgm_Srcs); shift; $(CHKSRC)

chkgen			::
			@set X $(Pgm_Prog); shift; $(CHKGEN)
			@set X $(Pgm_Help); shift; $(CHKGEN)

known			::
			@echo $(Pgm_Srcs) >> $(KNOWN)
			@echo $(Pgm_Objs) >> $(KNOWN)
			@echo $(Pgm_Prog) >> $(KNOWN)
			@echo $(Pgm_Help) >> $(KNOWN)

clean			::
			rm -f $(Pgm_Objs)

clobber			:: clean
			rm -f $(Pgm_Prog)
			rm -f $(Pgm_Help)

uninstall.bin		::
			cd $(BINDIR) && rm -f $(Pgm_Prog)

install.bin		:: chkgen uninstall.bin
			$(LN) $(Pgm_Prog) $(BINDIR)
			cd $(BINDIR) && chmod $(PROGPERM) $(Pgm_Prog)

uninstall.help		::
			cd $(HELPDIR) && rm -f $(Pgm_Help)

install.help		:: chkgen uninstall.help
			$(LN) $(Pgm_Help) $(HELPDIR)
			cd $(HELPDIR) && chmod $(RODATAPERM) $(Pgm_Help)


######################################################################
#-------
# McRD data files
#-------
#
#Data			= $(RelData) $(TxtData) $(BinData)
#

Data			=$(BinData)
 
#
#RelData			= \
# 			MAY97PRG.TXT
# 
#TxtData			= \
# 			CONTOUR.DEF
# 
#

BinData			= \
			ADVDISP.CORE\
			ADVSRY.DAT\
			AWSLOC.TXT\
			BD.ET\
			CIRCLE.CORE\
			DATOR\
			GMS5NAV\
			HURMAP-PLOTS.GIF\
			HURMAP1\
			HURMAP2\
			HURMAP3\
			HURMAP4\
			HURMAP5\
			HURMAP6\
			HURMAP7\
			HURMAP8\
			HURR-Atlantic-graphic\
			HURR-Atlantic\
			HURR-Caribbean-graphic\
			HURR-Caribbean\
			HURR-Pacific-graphic\
			HURR-Pacific\
			HURR.MCB\
			IAHWY151\
			IAHWY169\
			IAHWY18\
			IAHWY20\
			IAHWY218\
			IAHWY275\
			IAHWY30\
			IAHWY34\
			IAHWY52\
			IAHWY59\
			IAHWY61\
			IAHWY63\
			IAHWY65\
			IAHWY67\
			IAHWY69\
			IAHWY6\
			IAHWY71\
			IAHWY75\
			IAINT235\
			IAINT280\
			IAINT29\
			IAINT35\
			IAINT380\
			IAINT680\
			IAINT74\
			IAINT80\
			IMGMAKE.CORE\
			KALPANA1NAV\
			MASTBL50\
			MET5NAV\
			MET7NAV\
			MNHWY10\
			MNHWY12\
			MNHWY14\
			MNHWY169\
			MNHWY212\
			MNHWY218\
			MNHWY2\
			MNHWY52\
			MNHWY53\
			MNHWY59\
			MNHWY61\
			MNHWY63\
			MNHWY65\
			MNHWY69\
			MNHWY70\
			MNHWY71\
			MNHWY75\
			MNHWY8\
			MNINT35\
			MNINT90\
			MNINT94\
			MOSLIST.CORE\
			MSG48KM.MSK\
			OUTBRAZILST\
			OUTCANAL\
			OUTINGEO\
			OUTINPOL\
			OUTINSTA\
			OUTLSAFRST\
			OUTMEXICOST\
			OUTRAIL1\
			OUTRAIL2\
			OUTRAIL3\
			OUTSTHIW\
			OUTSTRD\
			OUTTECTN\
			OUTUSHIW\
			OUTUSINT\
			OUTUSRIV\
			OUTWOLAK\
			OUTWORIV\
			RADARDATA.CORE\
			RAWSATLOC.CFG\
			ROADMAP.CORE\
			TOPOIMG.ET\
			TORDEC.CFG\
			TORWARN.CORE\
			WIHWY10\
			WIHWY13\
			WIHWY141\
			WIHWY14\
			WIHWY151\
			WIHWY21\
			WIHWY29\
			WIHWY2\
			WIHWY35\
			WIHWY41\
			WIHWY45\
			WIHWY51\
			WIHWY53\
			WIHWY63\
			WIHWY70\
			WIHWY8\
			WIINT39\
			WIINT43\
			WIINT9039\
			WIINT909439\
			WIINT9094\
			WIINT90\
			WIINT94\
			gms5_BRITtoTEMP.wni\
			met5_BRITtoTEMP.wni\
			met7_BRITtoTEMP.wni\
			topography.image
 
chksrc			::
			@ set `	for f in $(Data)		\
			;	do	echo $(PKGDATA)/$$f	\
			;	done`				\
			; $(CHKSRC)
 
known			::
			@ for f in $(Data)			\
			; do	echo $(PKGDATA)/$$f		\
			; done >> $(KNOWN)
 
uninstall.data		::
			cd $(DATADIR) && rm -f $(Data)
 
install.data		:: uninstall.data
			cd $(PKGDATA) && $(DATALN) $(Data) $(DATADIR)
## Note: no chmod of source files (should be mode $(RODATAPERM))
#
#
######################################################################
#-------
# Man pages
#-------
#
#MANXREF			= \
#			xreftawk \
#			xref.tab
#
#MAN3PAGES1		= \
#                        McDitherPolygon.3 
#
#chksrc			::
#			@ set `	for f in $(MANXREF)		\
#			;	do	echo $(PKGMAN)/$$f	\
#			;	done`				\
#			; $(CHKSRC)
#			@ set `	for f in $(MAN3PAGES1)		\
#			;	do	echo $(PKGMAN)/$$f	\
#			;	done`				\
#			; $(CHKSRC)
#
#known			::
#			@ for f in $(MANXREF)			\
#			; do	echo $(PKGMAN)/$$f		\
#			; done >> $(KNOWN)
#			@ for f in $(MAN3PAGES1)		\
#			; do	echo $(PKGMAN)/$$f		\
#			; done >> $(KNOWN)
#
#uninstall.man		::
#			cd $(MANDIR) && rm -f $(MANXREF)
#			cd $(MANDIR)/man3 && rm -f $(MAN3PAGES1)
#
#install.man		:: uninstall.man
#			cd $(PKGMAN) && $(DATALN) $(MANXREF) $(MANDIR)
#			cd $(PKGMAN) && $(DATALN) $(MAN3PAGES1) $(MANDIR)/man3
# Note: no chmod of source files (should be mode $(RODATAPERM))

######################################################################
#-------
# miscellaneous dependencies
#-------

install		:: env  install.bin   install.lib
install		:: env  install.bin
uninstall	:: env uninstall.bin uninstall.lib
uninstall	:: env uninstall.bin
install		::  install.inc
uninstall	:: uninstall.inc

install.all	::  install   install.help
uninstall.all	:: uninstall uninstall.help
install.all	::  install.data
uninstall.all	:: uninstall.data
#install.all	::  install.man
#uninstall.all	:: uninstall.man

install.all.nogui	:: install.all
uninstall.all.nogui	:: uninstall.all
install.all.nox	:: install.all
uninstall.all.nox	:: uninstall.all

######################################################################
